summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Strong.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Strong.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Strong.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Strong.php b/includes/pear/Text/Wiki/Parse/Default/Strong.php
index 3fc4595..66ace75 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Strong.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Strong.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Strong.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -21,7 +21,7 @@
*
* Parses for strongly-emphasized text.
*
* This class implements a Text_Wiki_Parse to find source text marked for
* strong emphasis (bold) as defined by text surrounded by three
* single-quotes. On parsing, the text itself is left in place, but the
* starting and ending instances of three single-quotes are replaced with
@@ -35,7 +35,7 @@
*
*/
-class Text_Wiki_Parse_Strong extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Strong extends Text_Wiki_Parse {
/**
@@ -73,14 +73,14 @@ class Text_Wiki_Parse_Strong extends Text_Wiki_Parse {
function process(&$matches)
{
$start = $this->wiki->addToken(
- $this->rule, array('type' => 'start')
+ $this->rule, array("type" => "start")
);
$end = $this->wiki->addToken(
- $this->rule, array('type' => 'end')
+ $this->rule, array("type" => "end")
);
return $start . $matches[1] . $end;
}
}
-?> \ No newline at end of file
+?>
@@ -21,7 +21,7 @@
* Parses for strongly-emphasized text.
*
-* This class implements a Text_Wiki_Parse to find source text marked for
+* This class implements a Text_Wiki_Parse_Default to find source text marked for
* strong emphasis (bold) as defined by text surrounded by three
* single-quotes. On parsing, the text itself is left in place, but the